clear all
close all
clc
%% Main script for calculating force in lifting wire in jette operation
% Makes calls to the other functions
% Last updated at 08.06.2014, 13:56. 
%Calculate the force in the lifting wire and compare with the measurements
%Defining global parameters which will also be used in subroutines
%Plots the force in the lifting wire and statistical comparison
%Made at 14.06.2014, 04:08. 
%Call global parameters defined in the Main script
global  g cranedata count D dv rho_s thick nn time_tot H Ac Al Patm...
    gamma_a rho_a rho_w C

count=1;                        %Starting counter for figure plots
H=5.5;                          %Height of suction anchor
D=6;                            %Diameter of suction anchor
thick=0.02;                     %Wall thickness suction anchor
Ac=pi/4*(D-2*thick)^2;          %Area of air cushion
dv=[0.61 1.016];                %Diameter of small & large vent hatch
Al=(pi/4)*(dv(1,2)^2+dv(1,1)^2);
C=0.59;                         %Contraction coefficient
Patm=101300;                    %Atmospheric pressure
gamma_a=1.4;                    %Specific heat ratio of air
g=9.81;                         %Gravitational acceleration
rho_a=1.225;                    %Density of air at 15 degC
rho_w=1025;                     %Density seawater
rho_s=7850;                     %Density steel

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Importing data from full scale measurements
% From movies: Immersion of first anchor at: 02:06:11
% [num,txt,raw]=xlsread('cranedata.xlsx','FPSPLEM', 'C42177:J42589');
%Loading the cranedata.mat file containing the numerical data into the 
%vector data where the indices 1:8 represent the following 1:time [s], 
%2:wire force, 3: Crane tip velocity, 4: Crane tip acceleration, 5: 
%Roll motion of the vessel, 6: Pitch motion of the vessel, 7: Length of 
%payed out wire, 8: Wire speed
%save('crane_020620','num')     %Save this to directory to be loaded later
%Loading the crane and vessel measurements from the either the 
%crane_020606.mat or crane_020620.mat matrix where 17707.922 or 17722.484
%must be subtracted from time_load to start time at 0 and respectively
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Loading matrix for Jette-measurements
cranedata=load('crane_020620.mat');  
c_load=cranedata.num(:,2)*10^4;      %Wire load measured
%time_load defines the immersion of the first suction anchor (NE)
time_load=cranedata.num(:,1)-17722.484; %Time vector from operation 
%Interpolate to get new time vector
nn=1;                                   %Interpolation factor
time_tot=interp(time_load,nn);          %Interpolated time vector
c_interp=interp(c_load,nn);             %Interpolated wire load
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Calling the function jonsjette which calculates the wave elevation and its
%time derivative from the JONSWAP spectrum
waves(time_load);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Calling the heave-function which calculates the total interpolated
%lowering velocity and interpolated vertical motion of the suction anchors
%and saves these to files which will be evaluated for each time step
%inside the solveSE,NE,SW,NW functions
motion(time_load);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Calling the function which calculates the dynamic pressure with ODE45 a
%numerical solver for stiff problems
[mu_SE,mu_NE,mu_SW,mu_NW]=odesolvernew();

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% For calculating the slamming load on the suction anchor top Wagner's
% approach will be used.     
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[F_buoy_SE,F_buoy_NE,F_buoy_SW,F_buoy_NW]=...
    slam_func(mu_SE,mu_NE,mu_SW,mu_NW);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Calculate the force in the lifting wire
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Defining the static weight in air of the PLEM protection structure
F_stat=210*10^3*g;
F_wire=zeros(1,length(time_tot));   %Wire load
for i=1:length(time_tot)
    F_wire(i)=F_stat-F_buoy_SE(i)-F_buoy_NE(i)-F_buoy_SW(i)-F_buoy_NW(i);
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Plot force in lifting wire
count=count+1;
figure(count)
plot(time_tot,c_interp,time_tot,F_wire);...
    title('Force in lifting wire vs time');
% axes([])
legend('Measured wire force','Calculated wire force');
xlabel('Time [s]');
ylabel('Force [N]');
