%% Create Torsethaugen and directional spectrum
%This script creates the Torsethaugen and directional spectrum 
%Reference is made to WAFO-group
clear all
close all
clc
%Open the folder containing Wafo, then run initwafo.
%First create a spreading function from spreading.m as follows:
%Frequency independent: D = spreading(Nt,type,th0,data,w,def);
%Frequency dependent: D = D = spreading(th,type,th0,data,w,def);
%Loading matrix for Jette-measurements
cranedata=load('crane_020606.mat');    
time_load=cranedata.num(:,1)-17707.922; %Time vector from operation
%  D    = spreading function, struct reminding of spectrum struct   
%  th   = vector of direction angles, (default linspace(-pi,pi,Nt))
%  Nt   = scalar defining the length of th. (default 101)
%  type = type of spreading function, see options below (default 'cos2s')
%  th0  = vector or a scalar defining average direction at every frequency.
%         (length 1 or length == length(w)) (default 0)
%  data = vector of spreading parameters, see options below.
%        (default [15   15   0.52 5    -2.5  0    1    inf])
%  w    = frequency vector, if frequency dependent spreading 
%         (default linspace(0,3,257))
%  def  = 0 No frequency dependence of spreading function                
%         1 Mitsuyasu et al., Hasselman et al (JONSWAP experiment)
%         frequency dependent parametrization (default)
%type:'cos2s'  : cos-2s spreading    N(S)*[cos((th-th0)/2)]^(2*S)  (0 < S) 
%     'box'    : Box-car spreading   N(A)*I( -A < th-th0 < A)      (0 < A < pi)
%     'mises'  : von Mises spreading N(K)*exp(K*cos(th-th0))       (0 < K)
%     'poisson': Poisson spreading   N(X)/(1-2*X*cos(th-th0)+X^2)  (0 < X < 1)
%     'sech2'  : sech-2 spreading    N(B)*0.5*B*sech(B*(th-th0))^2 (0 < B)
%     'wnormal': Wrapped Normal      
%             [1 + 2*sum exp(-(n*D1)^2/2)*cos(n*(th-th0))]/(2*pi)  (0 < D1)
%           (N(.) = normalization factor)       
%           (the first letter is enough for unique identification)  
% frequency independent spreading:
%      data =  S,  default value: 15 which corresponds to 
%             'cos2s'  : S=15                      
%             'box'    : A=0.62   
%             'sech2'  : B=0.89      
%             'mises'  : K=8.3      
%             'poisson': X=0.94  
%             'wnormal': D=0.36
Hs=1.935;	
Hmax=3.55;
Tp=5.89;
Tz=4.634;
Nt=341;     
wc=2*pi/Tp;   %Angular cut-off frequency
def = 1;
type='cos2s';
spread_left=-55*pi/180;
spread_right=55*pi/180;
% th=linspace(spread_left,spread_right,Nt);
th0=0;  
% data=([15   15   0.52 5    -2.5  0    1    inf]);
data=15;
%Frequencies linearly distributed betweenn 0 and 33/Tp
w=linspace(0,33/Tp,(Nt));

D = spreading(Nt,type,th0,data,w,def);
%Now create a spectrum, here torsethaugen:
[S,Sw,Ss]=torsethaugen(w,[Hs Tp],1);
% Then create a new directional spectrum Snew with mkdspec:
Snew=mkdspec(S,D,1);
%Then create the realisations of the waves:
%  CALL:  [Y, Mv]=seasim(spec,Nx,Ny,Nt,dx,dy,dt,fftdim,plotflag)
%  
%         Y    = output struct with simulated path
%         Mv   = movie of output (run with movie(Mv))
%         spec = spectrum struct, must be two-dimensional spectrum
%         Nx,Ny,Nt = number of points in grid. Put Ny=0 for 2D simulation
%                    (default 2^7)
%         dx,dy,dt = steps in grid (default dx,dt by the Nyquist freq, dy=dx)
%         fftdim   = 1 or 2 gives one- or two dimensional FFT. (default 2) 
%                    If 1 then FFT over t and looping over x and y.
%                    If 2 then FFT2 over x and y, looping over t. 
%         plotflag = 0,1 or 2. If 0 no plot, if 2 movie (takes a couple of min.) 
%                    if 1 single (first) frame of movie (default 0)
%                     
%   The output struct contains:
%            .Z matrix of size [Ny Nx Nt], but with singleton dimensions removed 
%            .x, .t (and .y if Ny>1)  
%   For the removal of singleton dimensions, see SQUEEZE.
%Start the wave carpet from the center of the vessel with width= 48 [m]
% Ny=48;
% %Stepsize 1 [m] in transverse direction
% dy=1;
% fftdim=1;
% %Stepsize 1 [m] in longitudinal direction
% dx=1;
% dt=max(time_load)/Nt;
% %Length of wave carpet
% Nx=138;
% [Y, Mv]=seasim(Snew,Nx,Ny,Nt,dx,dy,dt,fftdim,1);
%plot the wave realisations
% plot(time_load,Y.Z(1,:));