function [omega_js1,zeta_js]=jonswap(time_tot)
%Creating JONSWAP spectrum
% eta3_dot=-0.98;
% H=6;

% N_t=1000;                           %Number of steps
% t_sub=(1.1*H)/abs(eta3_dot);        %Time until total submergence + 10% to
%                                     %ensure sufficient submergence
% step=t_sub/N_t;                     %Step size
             %Step through t_tot during lowering
Hs=0.1;          %Significant wave height estimated from video
Tp=4*sqrt(Hs);   %Peak period;mean limit from Marine dynamics lecture note
wp=2*pi/Tp;      %Peak frequency

%Steplength
b_js=max(time_tot);
a_js=min(time_tot);
deltaw=(b_js-a_js)/length(time_tot);
gamma_js=3.3;
S_js=zeros(1,length(time_tot));
omega_js1=zeros(1,length(time_tot));
omega_js2=zeros(1,length(time_tot));
      
for i=1:length(time_tot)
	%Calculates the frequency with midpoint formula
   	omega_js1(i)=a_js+(deltaw*(i-0.5));
	omega_js2(i)=wp/omega_js1(i);

	%Determines the shape function/std.deviation of the spectrum
    if (omega_js1(i) <= wp)
   		sig = 0.07;
   	else
   		sig = 0.09;
    end
    
	%The JONSWAP Spectrum is divided into parts for easier manipulation, then multiplied together.
  	S1 = (5/(32*pi));
    S2 = Hs^2*Tp*(1-(0.287*log(gamma_js)));
 	S3 = omega_js2(i)^5;
  	S4 = exp(-1.25*omega_js2(i)^4);
  	S5 = ((omega_js1(i)/wp)-1)^2;
  	S6 = exp(-S5/(2*sig^2));
  	S7 = gamma_js^S6;
	S_js(i)=S1*S2*S3*S4*S7;
        
end

zeta_js=sqrt(2*S_js*deltaw);             %Wave height from spectrum
% x_0=0;                                   %Evaluated at centre of anchor
% % Use a random phase angle such that no dominating wave component present
% epsilon=rand(1,length(time_tot))*2*pi;   %random number between 0 and 2pi
% % epsilon=load('epsilon.mat');
% zeta_inc=zeros(1,length(time_tot));      %Surface elevation
% zeta_inc_dot=zeros(1,length(time_tot));  %Time derivative surface elevation
% g=9.81;
% % Surface elevation needs to be superimposed
% for j=1:length(time_tot)
%     k_wave=omega_js1.^2/g;              %Wave number deep water
% %     Calculating surface elevation assuming deep water
%     zeta_inc(j)=sum(zeta_js.*cos(k_wave.*x_0...
%         -omega_js1.*time_tot(j)+epsilon)); 
%     zeta_inc_dot(j)=sum(zeta_js.*omega_js1.*sin(k_wave.*x_0...
%         -omega_js1.*time_tot(j)+epsilon));
% end
% figure(1)
% plot(time_tot,zeta_inc,'LineWidth',3); set(gca,'FontSize',15);
% title('Realizations of Jonswap spectrum');
% xlabel('time [s]');
% ylabel('Surface elevation');

% figure(1)
% plot(omega_js1,S_js,'LineWidth',3); set(gca,'FontSize',15);
% title('Jonswap spectrum');
% xlabel('\omega [rad/s]');
% ylabel('S [m^{2}s]')


end