
%% motion.m This function calculate vertical motion and velocity of 
% four suction anchors due to vessel motions and lowering velocity
% during splash zone transition
function motion(time_load)

global cranedata vel_fitted nn time_tot count s3_fitSE s3_fitNE s3_fitSW...
    s3_fitNW dsub_fit s3_SASE s3_SANE s3_SASW s3_SANW tip_vel vel_f vel...
    eta3_SE eta3_NE eta3_SW eta3_NW

%Coordinates for the four anchors relative to the MRU:
% x_c=[5.53 5.53 -10.27 -10.27]; 
% y_c=[18.86 31.5 18.86 31.5];

vel=cranedata.num(:,8);         %Lowering velocity from raw data
[B_f,A_f]=butter(4,0.1);        %Creating a low-pass filter
vel_f=filtfilt(B_f,A_f,vel);    %Filtered velocity
tip_vel=cranedata.num(:,3);     %Crane tip velocity from raw data
roll=cranedata.num(:,5);        %Roll motion from MRU
pitch=cranedata.num(:,6);       %Pitch motion from MRU

%Integrating the lowering velocity with the trapezoidal method to find the
%resulting vertical motion
dsub=zeros(1,length(time_load));
for i=2:length(time_load)
    dsub(i-1)=trapz(time_load(1:i),vel_f(1:i));
end
dsub(length(time_load))=trapz(time_load(1:length(time_load)),...
    vel_f(1:length(time_load)));
for i=2:length(time_load)
    test(i)=(dsub(i)-dsub(i-1))/(time_load(i)-time_load(i-1));
end

dsub_fit=fit(time_load,dsub','smoothingspline');
%Have to integrate the cranetip velocity to find the motion, also with the 
%trapezoidal method to find the resulting vertical motion:

s3_tip=zeros(1,length(time_load));
for i=2:length(time_load)
    s3_tip(i-1)=trapz(time_load(1:i),tip_vel(1:i));
end
s3_tip(length(time_load))=trapz(time_load(1:length(time_load)),...
    tip_vel(1:length(time_load)));

%Since the vessel is rolling about a mean value of 4.232 deg, this must be
%subtracted from the data values in addition to correct for degrees
roll_cor=(roll-mean(roll))*pi/180;
%Since the vessel is pitching about a mean value of -0.1908 deg this must
%be added to the data values in addition to correct for degrees
pitch_cor=(pitch-mean(pitch))*pi/180;
%Total vertical motion of MRU becomes:
yc=23.6;
xc=-2.37;
eta3_mru=zeros(1,length(time_load)); %Vertical motion of MRU
for i=1:length(time_load)
    eta3_mru(i)=s3_tip(i)-roll_cor(i)*yc+-pitch_cor(i)*xc;
end

% Plotting the total vertical velocity of the protection structure
% count=count+1;
% figure(count)
%subplot(311);plot(time_tot,vel_tot); title('Tot lowering velocity [m/s]');
%subplot(312);plot(time_tot,vel_f); title('Lowering vel from wire payout');
% subplot(313);plot(time_tot,tip_vel); title('Crane tip velocity');
% Plotting the roll,pitch and heave crane tip motion 
% count=count+1;
% figure(count)
% subplot(211); plot(time_load,roll,time_load,pitch);
% title('Crane tip motion due to roll & pitch [deg]');
% legend('Roll motion','Pitch motion');
% subplot(212); plot(time_load,roll_cor,time_load,pitch_cor);
% title('Corrected roll and pitch [rad]');
%Plot crane tip motion due to vessel motion
% count=count+1;
% figure(count)
% plot(time_test,s3_tip); title('Vertical crane tip motion [m]');

%Assuming a rigid connection between the ship and the hinged point
%of the suction anchors (due to large weight and tugger wires) then the
%vertical motion of the suction anchors due to vessel motion and lowering
%speed becomes:
y_1=23.6-7.9;
y_2=23.6+7.9;
x_1=5.53;
x_2=-10.27;

s3_SASE=zeros(1,length(time_load));  %Vert. mot. Southeast suction anchor
s3_SANE=zeros(1,length(time_load));  %Vert. mot. Northeast suction anchor
s3_SASW=zeros(1,length(time_load));  %Vert. mot. Southwest suction anchor
s3_SANW=zeros(1,length(time_load));  %Vert. mot. Northwest suction anchor

for i=1:length(time_load)
    s3_SASE(i)=dsub(i)+eta3_mru(i)+roll_cor(i)*y_1-pitch_cor(i)*x_1;
    s3_SANE(i)=dsub(i)+eta3_mru(i)+roll_cor(i)*y_2-pitch_cor(i)*x_1;
    s3_SASW(i)=dsub(i)+eta3_mru(i)+roll_cor(i)*y_1-pitch_cor(i)*x_2;
    s3_SANW(i)=dsub(i)+eta3_mru(i)+roll_cor(i)*y_2-pitch_cor(i)*x_2;
end

%Fitting a curve to these data by interpolation and saving the fitted data
%to variables which can be loaded when running the odesolver script
s3_fitSE=fit(time_load,s3_SASE','smoothingspline');
s3_fitNE=fit(time_load,s3_SANE','smoothingspline');
s3_fitSW=fit(time_load,s3_SASW','smoothingspline');
s3_fitNW=fit(time_load,s3_SANW','smoothingspline');
% save('s3SEsaved.mat','s3_fitSE');
% save('s3tSANE.mat','s3_fitNE');
% save('s3SASWe.mat','s3_fitSW');
% save('s3SANW.mat','s3_fitNW');
%Calculate velocity of each suction anchor
eta3_SE=zeros(1,length(time_load));
eta3_NE=zeros(1,length(time_load));
eta3_SW=zeros(1,length(time_load));
eta3_NW=zeros(1,length(time_load));

for i=2:length(time_load)
    eta3_SE(i-1)=(s3_SASE(i)-s3_SASE(i-1))/(time_load(i)-time_load(i-1));
    eta3_NE(i-1)=(s3_SANE(i)-s3_SANE(i-1))/(time_load(i)-time_load(i-1));
    eta3_SW(i-1)=(s3_SASW(i)-s3_SASW(i-1))/(time_load(i)-time_load(i-1));
    eta3_NW(i-1)=(s3_SANW(i)-s3_SANW(i-1))/(time_load(i)-time_load(i-1));
end

%No large error in having the last no. equal to zero.
%Use the linear extrapolation for the last entry in the anchor-velocities
% extrapSE=interp1(time_load(1:length(time_load)-1),..
% zeta_inc_dot_SE,'spline','pp');
% zeta_inc_dot_SE(length(time_load))=ppval(extrapSE,max(time_load));

%Saving the total lowering velocity to be used for solving the ODE for the
%dynamic air cushion pressure
vel_sum=vel_f+tip_vel;          %Total velocity of the suction anchor
%Interpolate to get a new velocity vector
% vel_tot=vel_sum;
%Plotting lowering speed of suction anchors
% count=count+1;
% figure(count)
% plot(time_tot,vel_tot); title('Total lowering velocity');
vel_fitted=fit(time_load,vel_sum,'smoothingspline');
% plot(time_tot,vel_tot,time_tot,feval(vel_fitted,time_tot));
% save('velsaved.mat','vel_fitted');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plotting the pitch and roll motion of the MRU
% count=1;
% count=count+1;
% figure(count)
% subplot(211);
% plot(time_load,roll); title('roll')
% subplot(212);
% plot(time_load,pitch); title('')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Plot total vertical motion of suction anchors
% count=count+1;
% figure(count)
% plot(time_load,s3_SASE,time_load,s3_SANE,...
% time_load,s3_SASW,time_load,s3_SANW);
% title('Vertical motion of Suction Anchors'); 
% legend('SE-SA','NE-SA','SW-SA','NW-SA');
% xlabel('time [s]'); ylabel('[m]')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Plot velocity of suction anchors
% count=count+1;
% figure(count)
% plot(time_load,eta3_SE,time_load,eta3_NE,...
% time_load,eta3_SW,time_load,eta3_NW);
% title('Vertical motion of Suction Anchors'); 
% legend('SE-SA','NE-SA','SW-SA','NW-SA');
% xlabel('time [s]'); ylabel('[m]')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plit vertical motion due to different contributions
% count=count+1;
% figure(count)
% plot(time_load,s3_tip); title('Vertical motion of crane tip');
% xlabel('time [s]'); ylabel('[m]')
% subplot(411); plot(time_load,dsub); 
% title('Vertical motion due to lowering vel');
% subplot(412); plot(time_load,s3_tip); 
% title('Vertical motion of crane tip');
% subplot(413); plot(time_load,vel_tot); title('Vertical vel of sa');
% subplot(414); plot(time_load,s3_SEi); title('Vertical motion of sa');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% count=count+1;
% % subplot(211); plot(time_tot,vel_f); title('Filtered lowering vel');
% subplot(212); plot(time_tot,tip_vel); 
% title('Crane tip velocity raw data');
end
