%% odesolvernew.m Calculation of the dynamic air cushion pressure 
%for four suction anchors
% This functions use input for the vertical motion of the suction anchors
% and wave elevations at each location for calculating the dynamic air
% cushion pressure inside each suction anchor.
function [y_SE,y_NE,y_SW,y_NW] = odesolvernew()

global time_tot g H Ac Al Patm gamma_a rho_a rho_w...
zeta_inc_fit_E zeta_inc_dot_fit_E zeta_inc_fit_W zeta_inc_dot_fit_W...
s3_fitSE s3_fitNE s3_fitSW s3_fitNW vel_fitted C

y0=0;                                   %Initial value for the dyn pressure
% myoptions=odeset('RelTol',0.0001);      %Defining tolerance level for the 
                                        %solution of the dynamic pressure                                   
% tic;    %Time-starter for the ode-function
%Calling the function which evaluates the right side of the equation for
%the dynamic air cushion pressure
[~,y_SE] = ode45(@solveSE,time_tot,y0);%,myoptions);
[~,y_NE] = ode45(@solveNE,time_tot,y0);%,myoptions);
[~,y_SW] = ode45(@solveSW,time_tot,y0);%,myoptions);
[~,y_NW] = ode45(@solveNW,time_tot,y0);%,myoptions);
% save('ySE.mat','y_SE');   %Save for checking the values of \mu afterwards
% save('yNE.mat','y_NE');   %Save for checking the values of \mu afterwards
% save('ySW.mat','y_SW');   %Save for checking the values of \mu afterwards
% save('yNW.mat','y_NW');   %Save for checking the values of \mu afterwards
% toc;

% count=count+1;
% figure(count)
% plot(t_SE,y_SE,t_NE,y_NE,t_SW,y_SW,t_NW,y_NW);
% title(['Calculating \mu with ode23tb in Matlab']);
% xlabel('Time [s]'); ylabel('Pressure [Pa]');
% legend('SE','NE','SW','NW');
% count=count+1;
% figure(count)
% plot(t,zeta_inc_eval); title('Wave elevation');
% count=count+1;
% figure(count)
% plot(t,dsub_eval); title('Vertical motion');
% count=count+1;
% figure(count)
% plot(t,vel_eval); title('Vertical motion');
% figure(2)
% plot(omega_js1,S_js,'LineWidth',3); set(gca,'FontSize',15);
% title('Jonswap spectrum');
% xlabel('\omega [rad/s]');
% ylabel('S [m^{2}s]')

function dydt = solveSE(time_t,u)
    
%Evaluating the fitted and saved values for the submergence level,
%total vertical velocity of the suction anchors and wave elevation/velocity
vel_eval=feval(vel_fitted,time_t);     %Total vertical velocity

dsub_eval=feval(s3_fitSE,time_t);        %Subm. level(heave motion)
%Evaluates the wave elevation
zeta_inc_eval=feval(zeta_inc_fit_E,time_t);  %Wave elevation
%Velocity of wave elevation
zeta_inc_dot_eval=feval(zeta_inc_dot_fit_E,time_t);  %Wave velocity                                                            

%Defining the right hand side of the derivative of the dynamic air cushion
%pressure which will be solved for each time instant during lowering

dydt=((zeta_inc_dot_eval-vel_eval-C*(Al/Ac)*sign(u)*sqrt(2*abs(u)/...
    rho_a))/(1/(gamma_a*Patm)*(1+((u)/Patm))^(-1)*(H+dsub_eval+((u)/...
    (rho_w*g))-zeta_inc_eval)+(1/(rho_w*g))));
end

function dydt = solveNE(time_t,u)

%Evaluating the saved values for the submergence level and total vertical
%velocity of the suction anchors
vel_eval=feval(vel_fitted,time_t);     %Total vertical velocity

dsub_eval=feval(s3_fitNE,time_t);        %Subm. level(heave motion)

zeta_inc_eval=feval(zeta_inc_fit_E,time_t);  %Wave elevation
%Velocity of wave elevation
zeta_inc_dot_eval=feval(zeta_inc_dot_fit_E,time_t);  %Wave velocity                                                            

%Defining the right hand side of the derivative of the dynamic air cushion
%pressure which will be solved for each time instant during lowering

dydt=((zeta_inc_dot_eval-vel_eval-C*(Al/Ac)*sign(u)*sqrt(2*abs(u)/...
    rho_a))/(1/(gamma_a*Patm)*(1+((u)/Patm))^(-1)*(H+dsub_eval+((u)/...
    (rho_w*g))-zeta_inc_eval)+(1/(rho_w*g))));
end

function dydt = solveSW(time_t,u)

%Evaluating the saved values for the submergence level and total vertical
%velocity of the suction anchors
vel_eval=feval(vel_fitted,time_t);     %Total vertical velocity

dsub_eval=feval(s3_fitSW,time_t);        %Subm. level(heave motion)

zeta_inc_eval=feval(zeta_inc_fit_W,time_t);  %Wave elevation
%Velocity of wave elevation
zeta_inc_dot_eval=feval(zeta_inc_dot_fit_W,time_t);  %Wave velocity                                                            

%Defining the right hand side of the derivative of the dynamic air cushion
%pressure which will be solved for each time instant during lowering

dydt=((zeta_inc_dot_eval-vel_eval-C*(Al/Ac)*sign(u)*sqrt(2*abs(u)/...
    rho_a))/(1/(gamma_a*Patm)*(1+((u)/Patm))^(-1)*(H+dsub_eval+((u)/...
    (rho_w*g))-zeta_inc_eval)+(1/(rho_w*g))));
end

function dydt = solveNW(time_t,u)

%Evaluating the saved values for the submergence level and total vertical
%velocity of the suction anchors
vel_eval=feval(vel_fitted,time_t);     %Total vertical velocity

dsub_eval=feval(s3_fitNW,time_t);        %Subm. level(heave motion)

zeta_inc_eval=feval(zeta_inc_fit_W,time_t);  %Wave elevation
%Velocity of wave elevation
zeta_inc_dot_eval=feval(zeta_inc_dot_fit_W,time_t);   %Wave velocity                                                           

%Defining the right hand side of the derivative of the dynamic air cushion
%pressure which will be solved for each time instant during lowering
% h=mupad('ump.mn');
dydt=((zeta_inc_dot_eval-vel_eval-C*(Al/Ac)*sign(u)*sqrt(2*abs(u)/rho_a...
   ))/(1/(gamma_a*Patm)*(1+((u)/Patm))^(-1)*(H+dsub_eval+((u)/(rho_w*g))...
    -zeta_inc_eval)+(1/(rho_w*g))));
end
end