%% rkown1.m Calculation of dynamic air cushion pressure by own algorithm
% Author: Torleif . Bertelsen 
% Last updated 10.03.2014
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clc
clear all
close all
global cranedata nn time_tot count g s3_SEi vel_fitted s3_fitSE...
zeta_inc_fit_E zeta_inc_dot_fit_E zeta_inc_fit_W...
    zeta_inc_dot_fit_W zeta_inc_main_E zeta_inc_main_W omega_js1 k_wave...
    v_water_E v_water_W
%Defining characteristic dimensions and physical properties
D=6;                              %Diameter of suction anchor
H=5.5;                            %Height of suction anchor
t=0.02;                             %Wall thickness suction anchor
Ac=pi/4*(D-2*t)^2;                      %Area of air cushion
dv=[0.61 1.02];                   %Diameter of small & large vent hatch
perf=0.019765;                      %Perforation ratio
% dve=(D)*sqrt(perf);                 %Diameter of vent hatch
Al=(pi/4)*dv(1,2)^2;                    %Leakage area
Patm=101300;                        %Atmospheric pressure
gamma_a=1.4;                        %Specific heat ratio of air
C_con=0.61;                         %Contraction coefficient
rho_a=1.225;                        %Density of air at 15 degC
rho_w=1025;                         %Density seawater
rho_s=7850;                         %Density steel
g=9.81;                             %Gravitational acceleration
%Wave data
Hs=1.895;                           %Characteristic significant wave height
Tz_buoy=5.89;% Or (8.9)*sqrt(Hs/g);   %Min zero crossing T from DNV-RP-H103
                                   %Should be larger or equal to 3.4 [s]
Tzmax=13;                          %Upper zero crossing T from DNV-RP-H103
omega_buoy=(2*pi)/Tz_buoy;         %Maximum wave frequency from DNV-RP-H103
lambda=(g*Tz_buoy^2)/(2*pi);         %Wave length for the most critical Tz
k=2*pi/lambda;                     %Wave number for lowest wavelengths

%Denoting time and u as symbols so they will not be calculated until 
%it is needed. (Here u is the dynamic pressure \mu) 

count=1;                                %Starting counter for figure plots
%Loading the crane and vessel measurements from the cdata.mat matrix
% cranedata=load('cdata.mat'); 
cranedata=load('crane_020620.mat'); 
cload=cranedata.num(:,2)*10^4;    %Crane load measured
syms t_t u
assume(u >= 0)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%% Calculating lowering velocity and submergence level %%%%%%%%%%%%
%Creating a new starting time for the wire-load measurements
%such that it starts on t=0 at the measuring time 11:00:21
nn=1;
time_jette=cranedata.num(:,1)-17722.484;
% time_jette=cranedata.num(:,1)-17707.922;
time_load=interp(time_jette,nn);          %Interpolated time vector
% steps=1/length(time_tot);
motion(time_jette);
syms d_tot w_tot

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%% Regular or constant waves %%%%%%%%%%%%%%%%%%%%%%%%

waves(time_jette);
x_E=round(91.42);                              %Eastern anchors' x-location
x_W=round(112.75);                             %Western anchors' x-location
y_S=round(18.8);
y_N=round(3);
% torset=load('dirsave.mat');
% zeta_inc_SE(:,1)=torset.dirsaved(y_S,x_E,:);

% zeta_inc_fitSE=fit(time_load,zeta_inc_SE,'smoothingspline');
% for i=1:length(time_load)-1
%     zeta_inc_dot_SE(i)=(zeta_inc_SE(i+1)-zeta_inc_SE(i))/...
%         (time_load(i+1)-time_load(i));
%     zeta_inc_dot_NE(i)=(zeta_inc_NE(i+1)-zeta_inc_NE(i))/...
% (time_load(i+1)-time_load(i));
%     zeta_inc_dot_SW(i)=(zeta_inc_SW(i+1)-zeta_inc_SW(i))/...
% (time_load(i+1)-time_load(i));
%     zeta_inc_dot_NW(i)=(zeta_inc_NW(i+1)-zeta_inc_NW(i))/...
% (time_load(i+1)-time_load(i));
% end
%Extrapolating to find the last value of the time derivative of wave elev.
% extrapSE=interp1(time_load(1:length(time_load)-1),...
%     zeta_inc_dot_SE,'spline','pp');
% zeta_inc_dot_SE(length(time_load))=ppval(extrapSE,max(time_load));
% zeta_inc_dot_fitSE=fit(time_load,zeta_inc_dot_SE','smoothingspline');

syms zeta_inc zeta_inc_dot


% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%% Calculate ODE using Runge-Kutta 4th order method %%%% 
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
N_t=10;

% time_int=0:time_step:max(time_load);
%Non-linear function of \mu and t on east side suction anchor
F_tu=((zeta_inc_dot-w_tot-C_con*(Al/Ac)*sign(u)*...
    sqrt((2*feval(symengine,'abs',u))/(rho_a)))/(1/(gamma_a*Patm)*...
    (1+u/Patm)^(-1)*(H+d_tot+u/(rho_w*g)-zeta_inc)+(1/(rho_w*g))));

for j=1:length(time_load)-1
    time_step(j)=(time_load(j+1)-time_load(j));
end

% uu = zeros(1,length(time_int));                       %Initial condition
% F_new=zeros(1,length(time_int));
% % % 
%Runge Kutta-4 Time integration loop  
u_new=zeros(1,length(time_load));
tic;
for i=1:(length(time_load)-1)                             %Calculation loop
%     assume(u_new>=0)
    d_new=feval(s3_fitSE,time_load(i));
    w_new=feval(vel_fitted,time_load(i));
    zeta_new=feval(zeta_inc_fit_E,time_load(i));
    zeta_inc_dot_new=feval(zeta_inc_dot_fit_E,time_load(i));
    F_new=subs(F_tu,[d_tot,w_tot,zeta_inc,zeta_inc_dot,u],...
        [d_new,w_new,zeta_new,zeta_inc_dot_new,u_new(i)]);
    
    a_1 = time_step(i)*F_new;
    
    d_new=feval(s3_fitSE,time_load(i)+0.5*time_step(i));
    w_new=feval(vel_fitted,time_load(i)+0.5*time_step(i));
    zeta_new=feval(zeta_inc_fit_E,time_load(i)+0.5*time_step(i));
    zeta_inc_dot_new=feval(zeta_inc_dot_fit_E,time_load(i)+...
        0.5*time_step(i));
    F_new=subs(F_tu,[d_tot,w_tot,zeta_inc,zeta_inc_dot,u],...
        [d_new,w_new,zeta_new,zeta_inc_dot_new,u_new(i)+0.5*a_1]);
    
    a_2 = time_step(i)*F_new;
    
    F_new=subs(F_tu,[d_tot,w_tot,zeta_inc,zeta_inc_dot,u],...
        [d_new,w_new,zeta_new,zeta_inc_dot_new,u_new(i)+0.5*a_2]);
    
    a_3 = time_step(i)*F_new;
    
    d_new=feval(s3_fitSE,time_load(i)+time_step(i));
    w_new=feval(vel_fitted,time_load(i)+time_step(i));
    zeta_new=feval(zeta_inc_fit_E,time_load(i)+time_step(i));
    zeta_inc_dot_new=feval(zeta_inc_dot_fit_E,time_load(i)+time_step(i));
    F_new=subs(F_tu,[d_tot,w_tot,zeta_inc,zeta_inc_dot,u],...
        [d_new,w_new,zeta_new,zeta_inc_dot_new,u_new(i)+a_3]);
    
    a_4 = time_step(i)*F_new;
    
    u_new(i+1) = u_new(i) + (1/6)*(a_1+2*a_2+2*a_3+a_4);  %main eq
%     error(i)=abs(uu(i+1)-uu(i));
%     Convergence criterion
%     if abs(uu(i+1)-uu(i))<1*10^-3
%         disp('conv');
%     else
%         break;
    
end
toc    %End of time measurement
save('mu_new.mat','u_new');
count=count+1;
figure(count)
plot(time_load,(u_new),'LineWidth',3); set(gca,'FontSize',15);
title(['Time integration of dynamic air cushion pressure \mu with RK4 '...
    'at no. of steps=', num2str(nn)]);
xlabel('time [s]');
ylabel('\mu(t) [Pa]');

