%% slam_func.m calculate buoyancy and slamming forces on suction anchors
% including slamming with Wagner's approach for a wedge in addition to two
% approaches with different slamming coefficients
function [F_buoy_SE,F_buoy_NE,F_buoy_SW,F_buoy_NW]=...
    slam_func(mu_SE,mu_NE,mu_SW,mu_NW)

%Last updated at 09.06.2014, 10:08. 
%Call global parameters defined in the Main script
global zeta_inc_main_E zeta_inc_main_W s3_SANE s3_SASE s3_SASW s3_SANW g...
     eta3_SE eta3_NE eta3_SW eta3_NW v_water_E v_water_W D ...
     time_tot H Ac rho_w count gamma_a Patm

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% For calculating the slamming load on the suction anchor top Wagner's
% approach for a wedge in addition to two different approaches with
%slamming coefficients will be used
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Ochi's criterion
v_ochi=0.093*sqrt(g*D);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Define Buoyancy force for the different suction anchors
F_buoy_SE=zeros(1,length(time_tot));
F_buoy_NE=zeros(1,length(time_tot));
F_buoy_SW=zeros(1,length(time_tot));
F_buoy_NW=zeros(1,length(time_tot));
%Define slamming forces for the different suction anchors
F_slam_SE=zeros(1,length(time_tot));
F_slam_NE=zeros(1,length(time_tot));
F_slam_SW=zeros(1,length(time_tot));
F_slam_NW=zeros(1,length(time_tot));
%Define slamming forces calculated with RP-H103 with for all anchors
% F_slam_SErp=zeros(1,length(time_tot));
% F_slam_NErp=zeros(1,length(time_tot));
% F_slam_SWrp=zeros(1,length(time_tot));
% F_slam_NWrp=zeros(1,length(time_tot));
%Define slamming pressures for the different suction anchors
P_slam_SE=zeros(1,length(time_tot));
P_slam_NE=zeros(1,length(time_tot));
P_slam_SW=zeros(1,length(time_tot));
P_slam_NW=zeros(1,length(time_tot));
%Define hydrodynamic pressures for the different suction anchors
P_hyd_SE=zeros(1,length(time_tot));
P_hyd_NE=zeros(1,length(time_tot));
P_hyd_SW=zeros(1,length(time_tot));
P_hyd_NW=zeros(1,length(time_tot));
%Define vertical motion and of inner surface of each suction anchor
zeta_iSE=zeros(1,length(time_tot));
zeta_iNE=zeros(1,length(time_tot));
zeta_iSW=zeros(1,length(time_tot));
zeta_iNW=zeros(1,length(time_tot));
%Define relative motion of inner surface for each suction anchor
wsurf_iNE=zeros(1,length(time_tot));
wsurf_iNW=zeros(1,length(time_tot));
wsurf_iSE=zeros(1,length(time_tot));
wsurf_iSW=zeros(1,length(time_tot));
%Relative velocity to be used in slamming calculations
v_slam_SE=zeros(1,length(time_tot));
v_slam_NE=zeros(1,length(time_tot));
v_slam_SW=zeros(1,length(time_tot));
v_slam_NW=zeros(1,length(time_tot));
%Counters for determining delay between the immersion of the different
%suction anchors
NW_delay=1.2;
SE_delay=6.6;
SW_delay=7.0;
%Starting counters that ensure that time delay between the different
%suction anchors are performed
c_NE=1;
c_SE=1;
c_SW=1;
c_NW=1;
%Counters for determining how many impacts that shall be included in the
%slamming calculations
NE_count=0;
NW_count=0;
SE_count=0;
SW_count=0;
%Counters used for saving the zero up-crossing values
k_NE=1;
k_NW=1;
k_SE=1;
k_SW=1;
for i=1:length(time_tot)
    
    zeta_iNE(i)=(zeta_inc_main_E(i)-mu_NE(i)/(rho_w*g));
    wsurf_iNE(i)=s3_SANE(i)-(zeta_iNE(i));  %Defined as negative
    %Define i >=2 to compare neighbouring values
    if i >=2
        %Save first zero down crossing-value
    if (wsurf_iNE(i-1)+H)*(wsurf_iNE(i)+H) <=0 
        NE_count=NE_count+1;
        save_NEi(NE_count)=(i);
        %Terminate loop if the succeeding impact is included
        if NE_count == 2
            break
        end
        
    end
    %Save first zero up-crossing-value 
    if NE_count >=1 && NE_count <= 2
        save_NE1(k_NE)=wsurf_iNE(i);
        k_NE=k_NE+1;
    end
    c_NE=c_NE+1;
    end
end
%Northwestern suction anchor
for i=1:length(time_tot)
    if time_tot(i) >= NW_delay
        zeta_iNW(i)=(zeta_inc_main_W(c_NW)-mu_NW(c_NW)/(rho_w*g)); 
        wsurf_iNW(i)=s3_SANW(c_NW)-(zeta_iNW(i));  %Defined as negative
    %Save first zero down crossing
    if i>=2
        if (wsurf_iNW(i-1)+H)*(wsurf_iNW(i)+H) <=0 
            NW_count=NW_count+1;
            save_NWi(NW_count)=(i);
            %Terminate loop if the succeeding impact is included
            if NW_count == 2
                break
            end
        
        end
        %Save first zero up-crossing 
        if NW_count >=1 && NW_count <= 2
            save_NW1(k_NW)=wsurf_iNW(i);
            k_NW=k_NW+1;
        end
    
    c_NW=c_NW+1;
    end
    end
end
%Southeastern suction anchor
for i=1:length(time_tot)
    if time_tot(i) >=SE_delay
    zeta_iSE(i)=(zeta_inc_main_E(c_SE)-mu_SE(c_SE)/(rho_w*g)); 
    wsurf_iSE(i)=s3_SASE(c_SE)-(zeta_iSE(i));  %Defined as negative
    if i>=2   
        %Save first 0 down- and up-crossing
    if (wsurf_iSE(i-1)+H)*(wsurf_iSE(i)+H) <=0 
        SE_count=SE_count+1;
        save_SEi(SE_count)=(i);
        
        if SE_count == 2
            break
        end
    end
        if SE_count >=1 && SE_count <= 2
            save_SE1(k_SE)=wsurf_iSE(i);
            k_SE=k_SE+1;
        end
    c_SE=c_SE+1;
    end
    end
    
end
%Southwestern suction anchor
for i=1:length(time_tot)
    if time_tot(i) >= SW_delay
        zeta_iSW(i)=(zeta_inc_main_W(c_SW)-mu_SW(c_SW)/(rho_w*g)); 
        wsurf_iSW(i)=s3_SASW(c_SW)-(zeta_iSW(i));  %Defined as negative
    if i>=2    
    if (wsurf_iSW(i-1)+H)*(wsurf_iSW(i)+H) <=0 
        %Save first zero down-crossing in first column
            SW_count=SW_count+1;
            save_SWi(SW_count)=(i);
            
        if SW_count == 2
            break
        end
    end
    %Save first zero up-crossing in first column
        if SW_count >=1 && SW_count <= 2
            save_SW1(k_SW)=wsurf_iSW(i);
            k_SW=k_SW+1;
        end
    c_SW=c_SW+1;
    end
    end
    
end
%Counter for immersion of succeding suction anchors
i_NW=1;     
i_SW=1;
i_SE=1;
%Index to be used for slamming-time calculations
slam_NE=1;
slam_NW=1;
slam_SE=1;
slam_SW=1;
%Deadrise angle in radians
beta=[5 10 17.5]*pi/180;
Cs=2*pi;                        %Slamming coefficient from Wagner
Vol_c=zeros(1,length(time_tot));
T_wn2=zeros(1,length(time_tot));
if length(save_NEi)==2
for i=1:length(time_tot)
    F_buoy_NE(i)=mu_NE(i)*Ac;     
    %Relative velocity before impact positive downwards
    v_slam_NE(i)=(eta3_NE(i)-v_water_E(i));
    %Local hydrostatic pressure
    P_hyd_NE(i)=rho_w*g*zeta_iNE(i);
    zeta_iNE(i)=(zeta_inc_main_E(i)-mu_NE(i)/(rho_w*g));
    wsurf_iNE(i)=s3_SANE(i)-(zeta_iNE(i));
    
    if  (i) >= (save_NEi(1)) && (i) <= (save_NEi(2))
        t_slam_NE(slam_NE)=time_tot(slam_NE);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            %Slamming force NE-anchor with slamming coefficient:
%     Cs_var_NE(i)=2*pi/(1+(1.5*v_slam_NE(i)*t_slam_NE(slam_NE)/(D/2))); 
%     F_slam_NE(i)=0.5*Cs_var_NE(i)*rho_w*Ac*v_slam_NE(i)^2;
%     F_slam_NErp(i)=0.5*Cs*rho_w*Ac*v_slam_NE(i)^2; 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %Slamming force with wedge-approximation
        F_slam_NE(i)=rho_w*(pi*2)*v_slam_NE(i)^4*...
            t_slam_NE(slam_NE)^2/(tan(beta(3)))^3;
        %Set dynamic air cushion pressure to zero
%         mu_NE(i)=0;
        F_buoy_NE(i)=F_slam_NE(i);
        P_slam_NE(i)=F_slam_NE(i)/Ac;
        %Set the slamming load to zero if the pressure after impact drops a
        %certain percentage
        if abs(v_slam_NE(i)) <= 0.8*v_ochi && P_slam_NE(i)...
                <= 1.2*abs(P_hyd_NE(i))
        %Another slamming criterion could be to say that if the pressure
        %reduce a certain percentage from the value at impact the slamming
        %can be considered finished  
            F_slam_NE(i)=0;
            F_buoy_NE(i)=mu_NE(i)*Ac;
            break
        
        end
        slam_NE=slam_NE+1;
    end
end
end
    %If there is no oscillation in and out out water during slamming
    %occurence, use contemporary satisfaction criteria only.
if length(save_NEi)~=2
    for i=1:length(time_tot)
         F_buoy_NE(i)=mu_NE(i)*Ac;     
    %Relative velocity before impact positive downwards
    v_slam_NE(i)=(eta3_NE(i)-v_water_E(i));
    %Local hydrostatic pressure
    P_hyd_NE(i)=rho_w*g*zeta_iNE(i);
    zeta_iNE(i)=(zeta_inc_main_E(i)-mu_NE(i)/(rho_w*g));
    wsurf_iNE(i)=s3_SANE(i)-(zeta_iNE(i));
    if wsurf_iNE(i) <= -H
        t_slam_NE(slam_NE)=time_tot(slam_NE);
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
            %Slamming force NE-anchor with slamming coefficient:
%     Cs_var_NE(i)=2*pi/(1+(1.5*v_slam_NE(i)*t_slam_NE(slam_NE)/(D/2))); 
%     F_slam_NE(i)=0.5*Cs_var_NE(i)*rho_w*Ac*v_slam_NE(i)^2;
%     F_slam_NErp(i)=0.5*Cs*rho_w*Ac*v_slam_NE(i)^2; 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        F_slam_NE(i)=rho_w*(pi*2)*v_slam_NE(i)^4*...
            t_slam_NE(slam_NE)^2/(tan(beta(3)))^3;

%         mu_NE(i)=0;
        F_buoy_NE(i)=F_slam_NE(i);
        P_slam_NE(i)=F_slam_NE(i)/Ac;
        %Set the slamming load to zero if the pressure after impact drops a
        %certain percentage
        if abs(v_slam_NE(i)) <= 0.8*v_ochi && P_slam_NE(i)...
                <= 1.2*abs(P_hyd_NE(i))
        %Another slamming criterion could be to say that if the pressure
        %reduce a certain percentage from the value at impact the slamming
        %can be considered finished  
            F_slam_NE(i)=0;
            F_buoy_NE(i)=mu_NE(i)*Ac;
            break
        end
        slam_NE=slam_NE+1;
        
    end
        
    end
end
    %Immersion of NW Suction anchor delayed by 1.2 [s]
if length(save_NWi)==2
for i = 1:length(time_tot)
    if time_tot(i) >= NW_delay
        zeta_iNW(i)=(zeta_inc_main_W(i_NW)-mu_NW(i_NW)/(rho_w*g)); 
        wsurf_iNW(i)=s3_SANW(i_NW)-(zeta_iNW(i));  %Defined as negative
        F_buoy_NW(i)=mu_NW(i_NW)*Ac;     
        v_slam_NW(i)=(eta3_NW(i_NW)-v_water_W(i_NW));
        P_hyd_NW(i)=rho_w*g*zeta_iNW(i);
     
        %Slamming criteria NW-anchor if the top is oscillating in and 
        %out of water
         if (i) >= (save_NWi(1)) && (i) <= (save_NWi(2))
            %Define starting time to be used in slamming calculations
            t_slam_NW(slam_NW)=time_tot(slam_NW);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %Slamming force with DNV-RP-H103 NW-anchor:
%        Cs_var_NW(i)=2*pi/(1+(1.5*v_slam_NW(i)*t_slam_NW(slam_NW)/(D/2))); 
%         F_slam_NW(i)=0.5*Cs_var_NW(i)*rho_w*Ac*v_slam_NW(i)^2;
%         F_slam_NWrp(i)=0.5*Cs*rho_w*Ac*v_slam_NW(i)^2; 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %Slamming force with wedge-approximation
         F_slam_NW(i)=rho_w*(pi*2)*v_slam_NW(i)^4*...
            t_slam_NW(slam_NW)^2/(tan(beta(3)))^3;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%             mu_NW(i)=0;
            F_buoy_NW(i)=F_slam_NW(i);
            P_slam_NW(i)=F_slam_NW(i)/Ac;
             %Stop slamming if contemporary satisfaction criteria is met
            if abs(v_slam_NW(i)) <= 0.8*v_ochi && P_slam_NW(i)...
                    <= 1.2*abs(P_hyd_NW(i))

                F_slam_NW(i)=0;
                F_buoy_NW(i)=mu_NW(i)*Ac;
                break
            end
            slam_NW=slam_NW+1;
         end
         i_NW=i_NW+1;
    end
end
end
 %Contemporary satisfaction criteria only
if length(save_NWi)~=2 
    for i=1:length(time_tot)
        if time_tot(i) >=NW_delay
        zeta_iNW(i)=(zeta_inc_main_W(i_NW)-mu_NW(i_NW)/(rho_w*g)); 
        wsurf_iNW(i)=s3_SANW(i_NW)-(zeta_iNW(i));  %Defined as negative    
        F_buoy_NW(i)=mu_NW(i_NW)*Ac;     
        v_slam_NW(i)=(eta3_NW(i_NW)-v_water_W(i_NW));
        P_hyd_NW(i)=rho_w*g*zeta_iNW(i);
        if wsurf_iNW(i) <= -H
            %Define starting time to be used in slamming calculations
            t_slam_NW(slam_NW)=time_tot(slam_NW);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %Slamming force with DNV-RP-H103 NW-anchor:
%        Cs_var_NW(i)=2*pi/(1+(1.5*v_slam_NW(i)*t_slam_NW(slam_NW)/(D/2))); 
%         F_slam_NW(i)=0.5*Cs_var_NW(i)*rho_w*Ac*v_slam_NW(i)^2;
%         F_slam_NWrp(i)=0.5*Cs*rho_w*Ac*v_slam_NW(i)^2; 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Slamming force with wedge-approximation
        F_slam_NW(i)=rho_w*(pi*2)*v_slam_NW(i)^4*...
            t_slam_NW(slam_NW)^2/(tan(beta(3)))^3;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%             mu_NW(i)=0;
            F_buoy_NW(i)=F_slam_NW(i);
            P_slam_NW(i)=F_slam_NW(i)/Ac;
             %Stop slamming if contemporary satisfaction criteria is met
            if abs(v_slam_NW(i)) <= 0.8*v_ochi && P_slam_NW(i)...
                    <= 1.2*abs(P_hyd_NW(i))
                
                F_slam_NW(i)=0; 
                F_buoy_NW(i)=mu_NW(i)*Ac;
                break
            end
            slam_NW=slam_NW+1;
        end
        i_NW=i_NW+1;
        end
    end
    
end

if length(save_SEi)==2        
for i=1:length(time_tot)
        %Immersion of SE Suction anchor delayed by 8.5 [s]
    if time_tot(i) >= SE_delay

        F_buoy_SE(i)=mu_SE(i_SE)*Ac;
        v_slam_SE(i)=(eta3_SE(i_SE)-v_water_E(i_SE));
        %Hydrostat pressure
        P_hyd_SE(i)=rho_w*g*zeta_iSE(i_SE);
   zeta_iSE(i)=(zeta_inc_main_E(i_SE)-mu_SE(i_SE)/(rho_w*g)); 
    wsurf_iSE(i)=s3_SASE(i_SE)-(zeta_iSE(i));  %Defined as negative
        %Slamming criteria SE-anchor
         if (i) >= (save_SEi(1)) && (i) <= (save_SEi(2))
            t_slam_SE(slam_SE)=time_tot(slam_SE);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %Slamming force with DNV-RP-H103 SE-anchor:
%        Cs_var_SE(i)=2*pi/(1+(1.5*v_slam_SE(i)*t_slam_SE(slam_SE)/(D/2))); 
%                 F_slam_SE(i)=0.5*Cs_var_SE(i)*rho_w*Ac*v_slam_SE(i)^2; 
%                 F_slam_SErp(i)=0.5*Cs*rho_w*Ac*v_slam_SE(i)^2; 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Slamming force with wedge-approximation
        F_slam_SE(i)=rho_w*(pi*2)*v_slam_SE(i)^4*...
            t_slam_SE(slam_SE)^2/(tan(beta(3)))^3;
%             mu_SE(i)=0;
            F_buoy_SE(i)=F_slam_SE(i);
            P_slam_SE(i)=F_slam_SE(i)/Ac;
        %Set the slamming load to zero if the pressure after impact drops a
        %certain percentage
            if abs(v_slam_SE(i)) <= 0.8*v_ochi && P_slam_SE(i)...
                    <= 1.2*abs(P_hyd_SE(i))
                F_slam_SE(i)=0;
                F_buoy_SE(i)=mu_SE(i)*Ac;
                break
            end
            slam_SE=slam_SE+1;
         end
         i_SE=i_SE+1;
    end
end
end

        %Contemporary satisfaction criteria for slamming duration only
if length(save_SEi) ~=2
    for i=1:length(time_tot)
        if time_tot(i) >= SE_delay
        F_buoy_SE(i)=mu_SE(i_SE)*Ac;
        v_slam_SE(i)=(eta3_SE(i_SE)-v_water_E(i_SE));
        %Hydrostat pressure
        P_hyd_SE(i)=rho_w*g*zeta_iSE(i_SE);
        zeta_iSE(i)=(zeta_inc_main_E(i_SE)-mu_SE(i_SE)/(rho_w*g)); 
    wsurf_iSE(i)=s3_SASE(i_SE)-(zeta_iSE(i));  %Defined as negative
        if wsurf_iSE(i) <= -H
            t_slam_SE(slam_SE)=time_tot(slam_SE);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %Slamming force with DNV-RP-H103 SE-anchor:
%        Cs_var_SE(i)=2*pi/(1+(1.5*v_slam_SE(i)*t_slam_SE(slam_SE)/(D/2))); 
%                 F_slam_SE(i)=0.5*Cs_var_SE(i)*rho_w*Ac*v_slam_SE(i)^2; 
%                 F_slam_SErp(i)=0.5*Cs*rho_w*Ac*v_slam_SE(i)^2; 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %Slamming force with wedge-approximation
        F_slam_SE(i)=rho_w*(pi*2)*v_slam_SE(i)^4*...
            t_slam_SE(slam_SE)^2/(tan(beta(3)))^3;
%             mu_SE(i)=0;
            F_buoy_SE(i)=F_slam_SE(i);
            P_slam_SE(i)=F_slam_SE(i)/Ac;
        %Set the slamming load to zero if the pressure after impact drops a
        %certain percentage
            if abs(v_slam_SE(i)) <= 0.8*v_ochi && P_slam_SE(i)...
                    <= 1.2*abs(P_hyd_SE(i))
                F_slam_SE(i)=0;
                F_buoy_SE(i)=mu_SE(i)*Ac;
                break
            end
            slam_SE=slam_SE+1;
        end
        
        i_SE=i_SE+1;
        end
    end
        
end
%Slamming criteria SW-anchor if the top is oscillating in and out of water      
if length(save_SWi)==2
    %Immersion of SW Suction anchor delayed by 1.7 [s]
for i=1:length(time_tot)
    if time_tot(i) >= SW_delay
        
        F_buoy_SW(i)=mu_SW(i_SW)*Ac;    
        v_slam_SW(i)=eta3_SW(i_SW)-v_water_W(i_SW);
        %Hydrostat pressure SW-anchor:
        P_hyd_SW(i)=rho_w*g*zeta_iSW(i);
        zeta_iSW(i)=(zeta_inc_main_W(i_SW)-mu_SW(i_SW)/(rho_w*g)); 
        wsurf_iSW(i)=s3_SASW(i_SW)-(zeta_iSW(i));  %Defined as negative
     
         if (i) >= (save_SWi(1)) && (i) <= (save_SWi(2))
            t_slam_SW(slam_SW)=time_tot(slam_SW);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %Slamming force with DNV-RP-H103 SE-anchor:
%        Cs_var_SW(i)=2*pi/(1+(1.5*v_slam_SW(i)*t_slam_SW(slam_SW)/(D/2))); 
%                 F_slam_SW(i)=0.5*Cs_var_SW(i)*rho_w*Ac*v_slam_SW(i)^2; 
%                 F_slam_SWrp(i)=0.5*Cs*rho_w*Ac*v_slam_SW(i)^2; 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %Slamming force with wedge-approximation
         F_slam_SW(i)=rho_w*(pi*2)*v_slam_SW(i)^4*...
             t_slam_SW(slam_SW)^2/(tan(beta(3)))^3;
%             mu_SW(i)=0;
            F_buoy_SW(i)=F_slam_SW(i);
            P_slam_SW(i)=F_slam_SW(i)/Ac;
            %Time-duration critera
            if abs(v_slam_SW(i)) <= 0.8*v_ochi && P_slam_SW(i)...
                    <= 1.2*abs(P_hyd_SW(i))
                F_slam_SW(i)=0;
                F_buoy_SW(i)=mu_SW(i)*Ac;
            break
            end
            slam_SW=slam_SW+1;
         end
         i_SW=i_SW+1;
    end
end
end
   
        %Contemporary satisfaction criteria only
if length(save_SWi) ~=2 
    for i=1:length(time_tot)
        if time_tot(i) >= SW_delay
        F_buoy_SW(i)=mu_SW(i_SW)*Ac;    
        v_slam_SW(i)=eta3_SW(i_SW)-v_water_W(i_SW);
        %Hydrostat pressure SW-anchor:
        P_hyd_SW(i)=rho_w*g*zeta_iSW(i);
        zeta_iSW(i)=(zeta_inc_main_W(i_SW)-mu_SW(i_SW)/(rho_w*g)); 
        wsurf_iSW(i)=s3_SASW(i_SW)-(zeta_iSW(i));  %Defined as negative
        
        if wsurf_iSW(i) <= -H
            t_slam_SW(slam_SW)=time_tot(slam_SW);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %Slamming force with DNV-RP-H103 SE-anchor:
%        Cs_var_SW(i)=2*pi/(1+(1.5*v_slam_SW(i)*t_slam_SW(slam_SW)/(D/2))); 
%                 F_slam_SW(i)=0.5*Cs_var_SW(i)*rho_w*Ac*v_slam_SW(i)^2; 
%                 F_slam_SWrp(i)=0.5*Cs*rho_w*Ac*v_slam_SW(i)^2; 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %Slamming force with wedge-approximation
         F_slam_SW(i)=rho_w*(pi*2)*v_slam_SW(i)^4*...
             t_slam_SW(slam_SW)^2/(tan(beta(3)))^3;

%             mu_SW(i)=0;
            F_buoy_SW(i)=F_slam_SW(i);
            P_slam_SW(i)=F_slam_SW(i)/Ac;
            %Time-duration critera
            if abs(v_slam_SW(i)) <= 0.8*v_ochi && P_slam_SW(i)...
                    <= 1.2*abs(P_hyd_SW(i))
                F_slam_SW(i)=0;
                F_buoy_SW(i)=mu_SW(i)*Ac;
            break
            end
            slam_SW=slam_SW+1;
        end
        i_SW=i_SW+1;
        end
    end
    
end
%Loop for calculation natural period in NE-SA
% omega_wn1=zeros(1,length(time_tot));
% omega_wn2=zeros(1,length(time_tot));
% T_wn1=zeros(1,length(time_tot));
% T_wn2=zeros(1,length(time_tot));
% for i=1:length(time_tot)
%     zeta_iNE(i)=(zeta_inc_main_W(i)-mu_NE(i)/(rho_w*g));
%     wsurf_iNE(i)=s3_SANE(i)-(zeta_iNE(i));
%     %Volume of air cushion
%     Vol_c(i)=Ac*(H-zeta_iNE(i)+s3_SANW(i));
%     if Vol_c(i) >= -0.1
%     omega_wn1(i)=sqrt((g+(Ac*gamma_a*(Patm+abs(mu_NW(i))))/...
%         (rho_w*Vol_c(i)))/((4*D)/(3*pi)+abs(wsurf_iNW(i))));
%     T_wn1(i)=2*pi/omega_wn1(i);  %Natural period of water and air coupled
%     omega_wn2(i)=sqrt(g/((4*D)/(3*pi)+abs(wsurf_iNW(i))));
%     %Defining the natural frequency of the oscillating water with the 
%     %atmospheric pressure as the upper boundary (uncoupled)
%     T_wn2(i)=2*pi/omega_wn2(i);   %Natural period of water uncoupled
%     end
% end
% save('omega_coupled.mat','omega_wn1')

% Plot time instants used in slamming calculations
% count=count+1;
% plot(time_tot,v_slam_SE,time_tot,v_slam_NE,...
%     time_tot,v_slam_SW,time_tot,v_slam_NW);
% title('Duration of slamming [s]')
% legend('Southeast-anchor','Northeast',...
%     ' Southwest','Northwest');
%Plot dynamic air cushion pressure
% count=count+1;
% figure(count)
% plot(time_tot,mu_SE,time_tot,mu_NE,time_tot,mu_SW,time_tot,mu_NW);
% title('Dynamic air cushion pressure');
% legend('\mu Southeast','\mu Northeast',...
%     '\mu Southwest ','\mu Northwest');
% xlabel('Time [s]');
% ylabel('[Pa]');
%Plot natural period according to Miles'
% count=count+1;
% figure(count)
% plot(time_tot,T_wn1,time_tot,T_wn2);
% title('Natural period coupled vs uncopled in NE-SA vs time');
% % legend('Coupled','Uncoupled');
% xlabel('Time [s]');
% ylabel('[s]');
% %Plot air cushion volume
% count=count+1;
% figure(count)
% plot(time_tot,Vol_c);
% title('Air-cushion volume in NE-SA vs time');
% % legend('Coupled','Uncoupled');
% xlabel('Time [s]');
% ylabel('[s]');
%Plot force in lifting wire
% count=count+1;
% figure(count)
% plot(time_tot,c_interp,time_tot,F_wire);...
%     title('Force in lifting wire vs time');
% % axes([])
% legend('Measured wire force','Calculated wire force');
% xlabel('Time [s]');
% ylabel('Force [N]');
% % Plot inner surface 
% count=count+1;
% figure(count)
% plot(time_tot,wsurf_iSE,time_tot,wsurf_iNE,...
%     time_tot,wsurf_iSW,time_tot,wsurf_iNW);
% title('Inner surface in suction anchors vs time');
% legend('Southeast anchor','Northeast anchor','Southwest anchor',...
%     'Northwest anchor');
% xlabel('Time [s]');
% ylabel(' [m]');
% count=count+1;
% figure(count)
% plot(time_tot,save_NEi);
% title('Inner surface in NE suction anchors vs time');
% % legend('Southeast anchor','Northeast anchor','Southwest anchor',...
% %     'Northwest anchor');
% xlabel('Time [s]');
% ylabel(' [m]');
%Plot relative velocity used in slam-calc
% count=count+1;
% figure(count)
% % % subplot(211),
% plot(time_tot,v_slam_SE,time_tot,v_slam_NE,...
%     time_tot,v_slam_SW,time_tot,v_slam_NW);
% title('Slamming velocity');
% legend('Rel vel Northeast','Rel vel Northwest',...
%     'Rel vel Southwest','Rel vel Southeast');
% xlabel('Time [s]');
% ylabel('[m/s]');
% Plot velocity of fluid particles
% count=count+1;
% figure(count)
% plot(time_tot,v_water_E,time_tot,v_water_W);
% title('Fluid velocity');
% xlabel('Time [s]');
% ylabel('[m/s]');
% legend('Wave velocity east','Wave velocity west');
%Plot slamming force
count=count+1;
figure(count)
plot(time_tot,F_slam_SE,time_tot,F_slam_NE,time_tot,...
    F_slam_SW,time_tot,F_slam_NW);
title(['Slamming force on suction anchors with Wagners model']);
legend('Southeast slamming','Northeast slamming',...
    'Southwest slamming','Northwest slamming');
axis([0 max(time_tot) 0 2.6*10^6]);
xlabel('Time [s]');
ylabel('Force [Pa]');
% subplot(212);
% plot(time_tot,F_slam_SErp,time_tot,F_slam_NErp,time_tot,...
%     F_slam_SWrp,time_tot,F_slam_NWrp);
% title('Slamming force on suction anchors with constant Cs');
% legend('Southeast slamming','Northeast slamming',...
%     'Southwest slamming','Northwest slamming');
% axis([0 max(time_tot) 0 2.6*10^6]);
% xlabel('Time [s]');
% ylabel('Force [Pa]');
% % subplot(313);
% plot(time_tot,F_slam_SErp1,time_tot,F_slam_NErp1,time_tot,...
%     F_slam_SWrp1,time_tot,F_slam_NWrp1);
% title('Slamming force on suction anchors with \beta=5 [deg]');
% legend('Southeast slamming','Northeast slamming',...
%     'Southwest slamming','Northwest slamming');
% axis([0 max(time_tot) 0 2.6*10^6]);
% xlabel('Time [s]');
% ylabel('Force [Pa]');
%Plot slamming pressure
% count=count+1;
% figure(count)
% plot(time_tot,P_slam_SE,time_tot,P_slam_NE,time_tot,...
%     P_slam_SW,time_tot,P_slam_NW);
% title('Slamming pressure on suction anchors vs time');
% legend('Southeast slamming','Northeast slamming',...
%     'Southwest slamming','Northwest slamming');
% % axis([0 max(time_tot) 0 2.3*10^6]);
% xlabel('Time [s]');
% ylabel('Force [Pa]');
end