%% waves.m This subroutine calculate wave realisations and velocities
% for both Jonswap spectrum and Torsethaugen spectrum
%Water particle velocities are also created
function waves(time_js)

global count g zeta_inc_fit_E zeta_inc_dot_fit_E zeta_inc_fit_W...
    zeta_inc_dot_fit_W zeta_inc_main_E zeta_inc_main_W omega_js1 k_wave...
    v_water_E v_water_W
Hs=1.935;	%Significant wave height from measurements
Hmax=3.55;  %Maximum wave height measured
Tp=5.89;    %Peak period from measurements
Tz=4.634;   %Zero crossing wave period
wp=2*pi/Tp; %Peak frequency
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Calculation of Jonswap spectrum
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Calculate Steplength
b_js=33/Tp;                         %Max frequency taken from Torsethaugen
a_js=0;                             %Min frequency
N=10000;                           %Number of steps in the spectrum-calc
deltaw=(b_js-a_js)/N;               %Steplength
gamma_js=exp(3.484*(1-0.1975*(0.036-0.0056*Tp/sqrt(Hs))*Tp^4/Hs^2));%3.3;
S_js=zeros(1,N);
% omega_js1=linspace(a_js,b_js,length(time_js));
% deltaw=omega_js1(2)-omega_js1(1);
omega_js1=zeros(1,N);
omega_js2=zeros(1,N);
      
for i=1:length(omega_js1)
	%Calculates the frequency with midpoint formula
   	omega_js1(i)=a_js+(deltaw*(i-0.5));
	omega_js2(i)=wp/omega_js1(i);

	%Determines the shape function/std.deviation of the spectrum
    if (omega_js1(i) <= wp)
   		sig = 0.07;
   	else
   		sig = 0.09;
    end
    
	%The JONSWAP Spectrum is divided into parts for easier manipulation,
    %then multiplied together.
  	S1 = (5/(32*pi));
    S2 = Hs^2*Tp*(1-(0.287*log(gamma_js)));
 	S3 = omega_js2(i)^5;
  	S4 = exp(-1.25*omega_js2(i)^4);
  	S5 = ((omega_js1(i)/wp)-1)^2;
  	S6 = exp(-S5/(2*sig^2));
  	S7 = gamma_js^S6;
	S_js(i)=S1*S2*S3*S4*S7;
        
end

zeta_js=sqrt(2*S_js*deltaw);                %Wave height from spectrum
k_wave=omega_js1.^2/g;                      %Wave number deep water
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Loading the spectral values for the two peaked Torsethaugen spectrum
%accounting both for wind and swell sea obtained from Wafo-script
S_load=load('S_th.mat');
S_th=S_load.Sth;
zeta_th=sqrt(2*S_th*deltaw);

%Specifying anchor positions relative to global reference system
x_E=5.53;                                   %Eastern anchors' x-location
x_W=-10.27;                                 %Western anchors' x-location
% % Use a random phase angle such that no dominating wave component present
%Saving a random number generator between 0 and 2pi which will be used
%later when calculating the surface elevation such that no dominating wave 
%component is present
% epsilon=rand(1,length(omega_js1))*2*pi;    %random number vector [0,2pi]
% save('epsilon.mat','epsilon');
eps_load=load('epsilon10000.mat');
%Wave elevation and velocity calculated from the Jonswap-spectrum
zeta_inc_jsE=zeros(1,length(time_js));
zeta_inc_dot_jsE=zeros(1,length(time_js));
zeta_inc_jsW=zeros(1,length(time_js));
zeta_inc_dot_jsW=zeros(1,length(time_js));
%%Wave elevation and velocity calculated from the Torsethaugen-spectrum
zeta_inc_thE=zeros(1,length(time_js));          %East realisations
zeta_inc_dot_thE=zeros(1,length(time_js));      %East wave velocities
zeta_inc_thW=zeros(1,length(time_js));          %West realisations
zeta_inc_dot_thW=zeros(1,length(time_js));      %West wave velocities
%Water particle velocity
v_water_E=zeros(1,length(time_js));
v_water_W=zeros(1,length(time_js));
%regular wave components
% zeta_inc_rE=zeros(1,length(time_js));
% zeta_inc_dot_rE=zeros(1,length(time_js));
% zeta_inc_rW=zeros(1,length(time_js));
% zeta_inc_dot_rW=zeros(1,length(time_js));
% omega_reg=2*pi/Tp;
% k_reg=omega_reg^2/g;

for i=1:length(time_js)

    for j=1:length(omega_js1)
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        % JONSWAP Wave realisations
    zeta_inc_jsE(i)=zeta_inc_jsE(i)+zeta_js(j)'.*...
    sin(omega_js1(j)*time_js(i)+k_wave(j)*x_E+eps_load.eps(j));
%     zeta_inc_dot_jsE(i)=zeta_inc_dot_jsE(i)+zeta_js(j)'.*...
% omega_js1(j).*cos(omega_js1(j)*time_js(i)...
%     +k_wave(j)*x_E+eps_load.eps(j));
%     zeta_inc_jsW(i)=zeta_inc_jsW(i)+zeta_js(j)'.*...
% sin(omega_js1(j)*time_js(i)+k_wave(j)*x_W+eps_load.eps(j));
%     zeta_inc_dot_jsW(i)=zeta_inc_dot_jsW(i)+zeta_js(j)'.*...
% omega_js1(j).*cos(omega_js1(j)*time_js(i)...
%     +k_wave(j)*x_W+eps_load.eps(j));

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %Torsethaugen Wave realisations
    zeta_inc_thE(i)=zeta_inc_thE(i)+zeta_th(j)'.*...
        sin(omega_js1(j)*time_js(i)+k_wave(j)*x_E+eps_load.eps(j));
    zeta_inc_dot_thE(i)=zeta_inc_dot_thE(i)+zeta_th(j)'.*omega_js1(j).*...
        cos(omega_js1(j)*time_js(i)...
    +k_wave(j)*x_E+eps_load.eps(j));
    zeta_inc_thW(i)=zeta_inc_thW(i)+zeta_th(j)'.*...
        sin(omega_js1(j)*time_js(i)+k_wave(j)*x_W+eps_load.eps(j));
    zeta_inc_dot_thW(i)=zeta_inc_dot_thW(i)+zeta_th(j)'.*omega_js1(j).*...
        cos(omega_js1(j)*time_js(i)...
    +k_wave(j)*x_W+eps_load.eps(j));
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %Water particle velocity
    v_water_E(i)=v_water_E(i)+omega_js1(j)*zeta_th(j)'*...
        cos(omega_js1(j)*time_js(i)+k_wave(j)*x_E+eps_load.eps(j));
    v_water_W(i)=v_water_W(i)+omega_js1(j)*zeta_th(j)'*...
        cos(omega_js1(j)*time_js(i)+k_wave(j)*x_W+eps_load.eps(j));
    
    end
    %What about regular waves? 
%    zeta_inc_rE(i)=Hs/2*sin(omega_reg*time_js(i)+k_reg*x_E);
%    zeta_inc_dot_rE(i)=omega_reg*Hs/2*cos(omega_reg*time_js(i)+k_reg*x_E);
%     zeta_inc_rW(i)=Hs/2*sin(omega_reg*time_js(i)+k_reg*x_W);
%    zeta_inc_dot_rW(i)=omega_reg*Hs/2*cos(omega_reg*time_js(i)+k_reg*x_W);
%     v_water_E(i)=omega_reg*Hs/2*cos(omega_reg*time_js(i)...
%       +k_reg*x_E);%+epsilon(j));
%     v_water_W(i)=omega_reg*Hs/2*cos(omega_reg*time_js(i)+...
%       k_reg*x_W);%+epsilon(j));
end
%Directional waves use both x- and y- coordinates of anchors:
x_E=round(91.42);                    %Eastern anchors' x-location
x_W=round(112.75);                   %Western anchors' x-location
y_S=round(18.8);
y_N=round(3);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Wave realizations created with directional spectrum with WAFO:
% zeta_spread=load('direct_new.mat');
% zeta_inc_SE(:,1)=zeta_spread.spread(y_S,x_E,:);
% zeta_inc_NE(:,1)=zeta_spread.spread(y_N,x_E,:);
% zeta_inc_SW(:,1)=zeta_spread.spread(y_S,x_W,:);
% zeta_inc_NW(:,1)=zeta_spread.spread(y_N,x_W,:);
%Forward differentiation to find wave velocity
% for i=1:length(time_load)-1
%     zeta_inc_dot_SE(i)=(zeta_inc_dE(i+1)-zeta_inc_dE(i))/...
% (time_js(i+1)-time_js(i));
%     zeta_inc_dot_NE(i)=(zeta_inc_NE(i+1)-zeta_inc_NE(i))/...
% (time_js(i+1)-time_js(i));
%     zeta_inc_dot_SW(i)=(zeta_inc_SW(i+1)-zeta_inc_SW(i))/...
% (time_js(i+1)-time_js(i));
%     zeta_inc_dot_NW(i)=(zeta_inc_NW(i+1)-zeta_inc_NW(i))/...
% (time_js(i+1)-time_js(i));
% end
% % %Extrapolating to find the last value of the time derivative of wave elev.
% extrapSE=interp1(time_js(1:length(time_js)-1),...
% zeta_inc_dot_SE,'spline','pp');
% zeta_inc_dot_SE(length(time_js))=ppval(extrapSE,max(time_js));
% extrapNE=interp1(time_js(1:length(time_js)-1),...
% zeta_inc_dot_NE,'spline','pp');
% zeta_inc_dot_NE(length(time_js))=ppval(extrapNE,max(time_js));
% extrapSW=interp1(time_js(1:length(time_js)-1),...
% zeta_inc_dot_SW,'spline','pp');
% zeta_inc_dot_SW(length(time_js))=ppval(extrapSW,max(time_js));
% extrapNW=interp1(time_js(1:length(time_js)-1),...
% zeta_inc_dot_NW,'spline','pp');
% zeta_inc_dot_NW(length(time_js))=ppval(extrapNW,max(time_js));
% zeta_inc_dot_fit_E=fit(time_load,zeta_inc_dot_SE','smoothingspline');

% zeta_inc_fit_E=fit(time_js,zeta_inc_rE','smoothingspline');
% zeta_inc_dot_fit_E=fit(time_js,zeta_inc_dot_rE','smoothingspline');
% zeta_inc_fit_W=fit(time_js,zeta_inc_rW','smoothingspline');
% zeta_inc_dot_fit_W=fit(time_js,zeta_inc_dot_rW','smoothingspline');
%Fitting a curve to the data resulting in piecewise expressions for the
%height and velocity of the wave elevation
%Jonswap %%%%%%%%%%%%%%%%%%%%%%%%%% CHANGE THIS %%%%%%%%%%%%%%%%%%%%%%
% zeta_inc_fit_E=fit(time_js,zeta_inc_jsE','smoothingspline');
% zeta_inc_dot_fit_E=fit(time_js,zeta_inc_dot_jsE','smoothingspline');
% zeta_inc_fit_W=fit(time_js,zeta_inc_jsW','smoothingspline');
% zeta_inc_dot_fit_W=fit(time_js,zeta_inc_dot_jsW','smoothingspline');
%Torsethaugen %%%%%%%%%%%%%%%%%%%%%%%%%% CHANGE THIS %%%%%%%%%%%%%%%%%%%%%%
zeta_inc_fit_E=fit(time_js,zeta_inc_thE','smoothingspline');
zeta_inc_dot_fit_E=fit(time_js,zeta_inc_dot_thE','smoothingspline');
zeta_inc_fit_W=fit(time_js,zeta_inc_thW','smoothingspline');
zeta_inc_dot_fit_W=fit(time_js,zeta_inc_dot_thW','smoothingspline');
% Directional Torsethaugen %%%%%%%%%%%%%%%%%% CHANGE THIS %%%%%%%%%%%%%%%%%
% zeta_inc_fit_SE=fit(time_js,zeta_inc_SE','smoothingspline');
% zeta_inc_dot_fit_SE=fit(time_js,zeta_inc_dot_SE','smoothingspline');
% zeta_inc_fit_SW=fit(time_js,zeta_inc_SW','smoothingspline');
% zeta_inc_dot_fit_SW=fit(time_js,zeta_inc_dot_SW','smoothingspline');
% zeta_inc_fit_NE=fit(time_js,zeta_inc_NE','smoothingspline');
% zeta_inc_dot_fit_NE=fit(time_js,zeta_inc_dot_NE','smoothingspline');
% zeta_inc_fit_NW=fit(time_js,zeta_inc_NW','smoothingspline');
% zeta_inc_dot_fit_NW=fit(time_js,zeta_inc_dot_NW','smoothingspline');
% Determine which type of wave elevation to be exported to the force
%calculations
zeta_inc_main_E=zeta_inc_thE;   %Output wave elevation for eastern anchors
zeta_inc_main_W=zeta_inc_thW;   %Output wave elevation for western anchors

%Plot comparison between wave realisations with unidirectional and
%directional Torsethaugen and unidirectional JONSWAP
% count=count+1;
% figure(count)
% subplot(311),
% plot(time_js,zeta_inc_thE);
% title('Realizations of Torsethaugen waves at East-anchors');
% xlabel('time [s]');
% ylabel('Surface elevation [m]');
% subplot(312), plot(time_js,zeta_inc_jsE);
% title('Realizations of JONSWAP-spectrum at East-anchors');
% xlabel('time [s]');
% ylabel('Surface elevation [m]');
% subplot(313), plot(time_js,zeta_inc_SE);
% title(['Realizations of Directional-Torsethaugen-spectrum'...
%     ' at Southeast-anchor']);
% xlabel('time [s]');
% ylabel('Surface elevation [m]');
%Plot realisations together
% count=count+1;
% figure(count)
% plot(time_js,zeta_inc_SE,time_js,zeta_inc_thE,time_js,zeta_inc_jsE); 
% set(gca,'FontSize',30);
% title('Comparison of wave realizations versus time');
% legend('Short crested-Torsethaugen','Long crested Torsethaugen',...
%     'JONSWAP');
% xlabel('Time [s]');
% ylabel('S [m^{2}s]');
% count=count+1;
% figure(count)
% plot(time_js,zeta_inc_thE,time_js,zeta_inc_jsE); 
% % set(gca,'FontSize',30);
% title('Comparison of long crested wave realizations versus time');
% legend('Torsethaugen',...
%     ' JONSWAP');
% xlabel('Time [s]');
% ylabel('S [m^{2}s]');
% count=count+1;
% figure(count)
% plot(omega_js1,S_js,'LineWidth',3); set(gca,'FontSize',15);
% title('Jonswap spectrum');
% xlabel('\omega [rad/s]');
% ylabel('S [m^{2}s]');
end